# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.utilities import language_pb2 as v1_dot_utilities_dot_language__pb2


class LanguageServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.LanguageAdd = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.language.LanguageService/LanguageAdd",
            request_serializer=v1_dot_utilities_dot_language__pb2.LanguageAddRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_language__pb2.LanguageAddResponse.FromString,
        )
        self.LanguageRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.language.LanguageService/LanguageRead",
            request_serializer=v1_dot_utilities_dot_language__pb2.LanguageReadRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_language__pb2.LanguageReadResponse.FromString,
        )
        self.LanguageUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.language.LanguageService/LanguageUpdate",
            request_serializer=v1_dot_utilities_dot_language__pb2.LanguageUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_language__pb2.LanguageUpdateResponse.FromString,
        )
        self.LanguageDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.language.LanguageService/LanguageDelete",
            request_serializer=v1_dot_utilities_dot_language__pb2.LanguageDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_language__pb2.LanguageDeleteResponse.FromString,
        )


class LanguageServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def LanguageAdd(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LanguageRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LanguageUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LanguageDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_LanguageServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "LanguageAdd": grpc.unary_unary_rpc_method_handler(
            servicer.LanguageAdd,
            request_deserializer=v1_dot_utilities_dot_language__pb2.LanguageAddRequest.FromString,
            response_serializer=v1_dot_utilities_dot_language__pb2.LanguageAddResponse.SerializeToString,
        ),
        "LanguageRead": grpc.unary_unary_rpc_method_handler(
            servicer.LanguageRead,
            request_deserializer=v1_dot_utilities_dot_language__pb2.LanguageReadRequest.FromString,
            response_serializer=v1_dot_utilities_dot_language__pb2.LanguageReadResponse.SerializeToString,
        ),
        "LanguageUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.LanguageUpdate,
            request_deserializer=v1_dot_utilities_dot_language__pb2.LanguageUpdateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_language__pb2.LanguageUpdateResponse.SerializeToString,
        ),
        "LanguageDelete": grpc.unary_unary_rpc_method_handler(
            servicer.LanguageDelete,
            request_deserializer=v1_dot_utilities_dot_language__pb2.LanguageDeleteRequest.FromString,
            response_serializer=v1_dot_utilities_dot_language__pb2.LanguageDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.utilities.language.LanguageService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class LanguageService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def LanguageAdd(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.language.LanguageService/LanguageAdd",
            v1_dot_utilities_dot_language__pb2.LanguageAddRequest.SerializeToString,
            v1_dot_utilities_dot_language__pb2.LanguageAddResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LanguageRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.language.LanguageService/LanguageRead",
            v1_dot_utilities_dot_language__pb2.LanguageReadRequest.SerializeToString,
            v1_dot_utilities_dot_language__pb2.LanguageReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LanguageUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.language.LanguageService/LanguageUpdate",
            v1_dot_utilities_dot_language__pb2.LanguageUpdateRequest.SerializeToString,
            v1_dot_utilities_dot_language__pb2.LanguageUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LanguageDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.language.LanguageService/LanguageDelete",
            v1_dot_utilities_dot_language__pb2.LanguageDeleteRequest.SerializeToString,
            v1_dot_utilities_dot_language__pb2.LanguageDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
