# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/ms.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15v1/utilities/ms.proto\x12*pro.omni.oms.api.v1.utilities.microservice\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xa5\x03\n\x0cMicroservice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0e\n\x06sumary\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x06 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x07 \x01(\t\x12\x0f\n\x07version\x18\x08 \x01(\t\x12\x0f\n\x07\x64\x65pends\x18\t \x03(\t\x12(\n\x04\x64\x61ta\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12-\n\tload_data\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12)\n\x08settings\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06\x61\x63tive\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x0e \x01(\t\x12?\n\x0cobject_audit\x18\x0f \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf1\x02\n\x19MicroserviceCreateRequest\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0e\n\x06sumary\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x06 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x07 \x01(\t\x12\x0f\n\x07version\x18\x08 \x01(\t\x12\x0f\n\x07\x64\x65pends\x18\t \x03(\t\x12(\n\x04\x64\x61ta\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12-\n\tload_data\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12)\n\x08settings\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0b\x65xternal_id\x18\r \x01(\t\x12\x36\n\x07\x63ontext\x18\x0e \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb7\x01\n\x1aMicroserviceCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12N\n\x0cmicroservice\x18\x02 \x01(\x0b\x32\x38.pro.omni.oms.api.v1.utilities.microservice.Microservice"\xf5\x02\n\x17MicroserviceReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf1\x01\n\x18MicroserviceReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12O\n\rmicroservices\x18\x03 \x03(\x0b\x32\x38.pro.omni.oms.api.v1.utilities.microservice.Microservice"\xa3\x01\n\x19MicroserviceUpdateRequest\x12N\n\x0cmicroservice\x18\x01 \x01(\x0b\x32\x38.pro.omni.oms.api.v1.utilities.microservice.Microservice\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb7\x01\n\x1aMicroserviceUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12N\n\x0cmicroservice\x18\x02 \x01(\x0b\x32\x38.pro.omni.oms.api.v1.utilities.microservice.Microservice"_\n\x19MicroserviceDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"g\n\x1aMicroserviceDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xaf\x05\n\x13MicroserviceService\x12\xa5\x01\n\x12MicroserviceCreate\x12\x45.pro.omni.oms.api.v1.utilities.microservice.MicroserviceCreateRequest\x1a\x46.pro.omni.oms.api.v1.utilities.microservice.MicroserviceCreateResponse"\x00\x12\x9f\x01\n\x10MicroserviceRead\x12\x43.pro.omni.oms.api.v1.utilities.microservice.MicroserviceReadRequest\x1a\x44.pro.omni.oms.api.v1.utilities.microservice.MicroserviceReadResponse"\x00\x12\xa5\x01\n\x12MicroserviceUpdate\x12\x45.pro.omni.oms.api.v1.utilities.microservice.MicroserviceUpdateRequest\x1a\x46.pro.omni.oms.api.v1.utilities.microservice.MicroserviceUpdateResponse"\x00\x12\xa5\x01\n\x12MicroserviceDelete\x12\x45.pro.omni.oms.api.v1.utilities.microservice.MicroserviceDeleteRequest\x1a\x46.pro.omni.oms.api.v1.utilities.microservice.MicroserviceDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.ms_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_MICROSERVICE"]._serialized_start = 151
    _globals["_MICROSERVICE"]._serialized_end = 572
    _globals["_MICROSERVICECREATEREQUEST"]._serialized_start = 575
    _globals["_MICROSERVICECREATEREQUEST"]._serialized_end = 944
    _globals["_MICROSERVICECREATERESPONSE"]._serialized_start = 947
    _globals["_MICROSERVICECREATERESPONSE"]._serialized_end = 1130
    _globals["_MICROSERVICEREADREQUEST"]._serialized_start = 1133
    _globals["_MICROSERVICEREADREQUEST"]._serialized_end = 1506
    _globals["_MICROSERVICEREADRESPONSE"]._serialized_start = 1509
    _globals["_MICROSERVICEREADRESPONSE"]._serialized_end = 1750
    _globals["_MICROSERVICEUPDATEREQUEST"]._serialized_start = 1753
    _globals["_MICROSERVICEUPDATEREQUEST"]._serialized_end = 1916
    _globals["_MICROSERVICEUPDATERESPONSE"]._serialized_start = 1919
    _globals["_MICROSERVICEUPDATERESPONSE"]._serialized_end = 2102
    _globals["_MICROSERVICEDELETEREQUEST"]._serialized_start = 2104
    _globals["_MICROSERVICEDELETEREQUEST"]._serialized_end = 2199
    _globals["_MICROSERVICEDELETERESPONSE"]._serialized_start = 2201
    _globals["_MICROSERVICEDELETERESPONSE"]._serialized_end = 2304
    _globals["_MICROSERVICESERVICE"]._serialized_start = 2307
    _globals["_MICROSERVICESERVICE"]._serialized_end = 2994
# @@protoc_insertion_point(module_scope)
